@@ -18,15 +18,23 @@ from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
 import pkg_resources
 
 import google.auth  # type: ignore
-import google.api_core  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.recommender_v1beta1.types import insight
+from google.cloud.recommender_v1beta1.types import insight_type_config
+from google.cloud.recommender_v1beta1.types import (
+    insight_type_config as gcr_insight_type_config,
+)
 from google.cloud.recommender_v1beta1.types import recommendation
+from google.cloud.recommender_v1beta1.types import recommender_config
+from google.cloud.recommender_v1beta1.types import (
+    recommender_config as gcr_recommender_config,
+)
 from google.cloud.recommender_v1beta1.types import recommender_service
 
 try:
@@ -103,7 +111,6 @@ class RecommenderTransport(abc.ABC):
             credentials, _ = google.auth.load_credentials_from_file(
                 credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
-
         elif credentials is None:
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
@@ -203,6 +210,26 @@ class RecommenderTransport(abc.ABC):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.get_recommender_config: gapic_v1.method.wrap_method(
+                self.get_recommender_config,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.update_recommender_config: gapic_v1.method.wrap_method(
+                self.update_recommender_config,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_insight_type_config: gapic_v1.method.wrap_method(
+                self.get_insight_type_config,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.update_insight_type_config: gapic_v1.method.wrap_method(
+                self.update_insight_type_config,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -292,5 +319,53 @@ class RecommenderTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_recommender_config(
+        self,
+    ) -> Callable[
+        [recommender_service.GetRecommenderConfigRequest],
+        Union[
+            recommender_config.RecommenderConfig,
+            Awaitable[recommender_config.RecommenderConfig],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def update_recommender_config(
+        self,
+    ) -> Callable[
+        [recommender_service.UpdateRecommenderConfigRequest],
+        Union[
+            gcr_recommender_config.RecommenderConfig,
+            Awaitable[gcr_recommender_config.RecommenderConfig],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_insight_type_config(
+        self,
+    ) -> Callable[
+        [recommender_service.GetInsightTypeConfigRequest],
+        Union[
+            insight_type_config.InsightTypeConfig,
+            Awaitable[insight_type_config.InsightTypeConfig],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def update_insight_type_config(
+        self,
+    ) -> Callable[
+        [recommender_service.UpdateInsightTypeConfigRequest],
+        Union[
+            gcr_insight_type_config.InsightTypeConfig,
+            Awaitable[gcr_insight_type_config.InsightTypeConfig],
+        ],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("RecommenderTransport",)
